@rem======================================================================
@rem
@rem    setup.bat
@rem
@rem======================================================================
@echo off
setlocal
pushd .

goto LInitialize

@rem----------------------------------------------------------------------
@rem    LInitialize
@rem----------------------------------------------------------------------
:LInitialize
	if defined CommonProgramW6432 (
        (set "UsableCommon=%CommonProgramW6432%") 
    ) else (
        (set "UsableCommon=%CommonProgramFiles%")
    )
	
	if  exist "%UsableCommon%\Microsoft Shared\web server extensions\15" (
        (goto :sp15)
    )
	if  exist "%UsableCommon%\Microsoft Shared\web server extensions\14" (
        (goto :sp14)
    )
	if  exist "%UsableCommon%\Microsoft Shared\web server extensions\12" (
        (goto :sp12)
    )
	
    :sp15
	set "SPLocation=%UsableCommon%\Microsoft Shared\web server extensions\15"
	set SPVersion=15
	goto :next

    :sp14
	set "SPLocation=%UsableCommon%\Microsoft Shared\web server extensions\14"
	set SPVersion=14
	goto :next

    :sp12
	set "SPLocation=%UsableCommon%\Microsoft Shared\web server extensions\12"
	set SPVersion=12
	goto :next
	
	:next	
    (set "SPAdminTool=%SPLocation%\BIN\stsadm.exe")
    set Install=
    set Uninstall=
    (set "PackageFile=%~dp0SAS.WebParts.wsp")
    set PackageName=SAS.WebParts.wsp
    set DefaultWebUrl=http://localhost
    set DefaultSiteUrl=http://localhost
    set TargetWebUrl=
    set TargetSiteUrl=
    (set "SPTemplateLocation=%SPLocation%\template")
    (set "SPFeaturesLocation=%SPTemplateLocation%\features")
    (set "SPSiteTemplateLocation=%SPTemplateLocation%\sitetemplates")
    set ValidationFailed=

    goto LParseArgs


@rem----------------------------------------------------------------------
@rem    LParseArgs
@rem----------------------------------------------------------------------
:LParseArgs
    @rem --- help ---
    if "%1" == "/?"    goto LHelp
    if "%1" == "-?"    goto LHelp
    if "%1" == "/h"    goto LHelp
    if "%1" == "-h"    goto LHelp
    if "%1" == "/help" goto LHelp
    if "%1" == "-help" goto LHelp

    @rem --- Fix execute task ---
    if "%1" == "/i"         (set Install=1)   & shift & goto LParseArgs
    if "%1" == "-i"         (set Install=1)   & shift & goto LParseArgs
    if "%1" == "/install"   (set Install=1)   & shift & goto LParseArgs
    if "%1" == "-install"   (set Install=1)   & shift & goto LParseArgs
    if "%1" == "/u"         (set Uninstall=1) & shift & goto LParseArgs
    if "%1" == "-u"         (set Uninstall=1) & shift & goto LParseArgs
    if "%1" == "/uninstall" (set Uninstall=1) & shift & goto LParseArgs
    if "%1" == "-uninstall" (set Uninstall=1) & shift & goto LParseArgs
    
    @rem --- Fix url ---
    if "%1" == "/weburl"  (set TargetWebUrl=%2)  & shift & shift & goto LParseArgs
    if "%1" == "-weburl"  (set TargetWebUrl=%2)  & shift & shift & goto LParseArgs
    if "%1" == "/siteurl" (set TargetSiteUrl=%2) & shift & shift & goto LParseArgs
    if "%1" == "-siteurl" (set TargetSiteUrl=%2) & shift & shift & goto LParseArgs

    @rem --- Check invalid arguments ---
    if not "%1" == "" (
        echo Invalid argument.
        goto LHelp
    )

    @rem --- Check arguments ---
    if "%Install%" == "1" (
        if "%Uninstall%" == "1" (
            goto LHelp
        )
    )

    if "%Install%" == "" (
        if "%Uninstall%" == "" (
            set Install=1
        )
    )

    if "%TargetSiteUrl%" == "" (
        if "%TargetWebUrl%" == "" (
            set TargetWebUrl=%DefaultWebUrl%
            set TargetSiteUrl=%DefaultSiteUrl%
        )
        if not "%TargetWebUrl%" == "" (
            set TargetSiteUrl=%TargetWebUrl%
            echo Setting TargetSiteUrl to be %TargetWebUrl%
        )
    )

    if "%TargetWebUrl%" == "" (
        set TargetWebUrl=%TargetSiteUrl%
        echo Setting TargetWebUrl to be %TargetSiteUrl%
    )

	goto LMain


@rem----------------------------------------------------------------------
@rem	LHelp
@rem----------------------------------------------------------------------
:LHelp
    echo Usage:
    echo setup.bat [/install or /uninstall][/weburl ^<url^>][/siteurl ^<url^>]
    echo           [/help]
    echo.
    echo Options:
    echo  /install or /uninstall
    echo  Install specified Solution package (.wsp) to the SharePoint server
    echo  or uninstall specified Solution from the SharePoint server.
    echo  Default value: install
    echo  /weburl
    echo  Specify a web url of the SharePoint server.
    echo  Default value: %DefaultWebUrl%
    echo  /siteurl
    echo  Specify a site url of the SharePoint server.
    echo  Default value: %DefaultSiteUrl%
    echo  /help
    echo  Show this information.
    echo.

	goto LTerminate


@rem----------------------------------------------------------------------
@rem    LMain
@rem----------------------------------------------------------------------
:LMain
	if "%Install%" == "1" (
      call :LValidate
  )
	if "%Install%" == "1" (
	   if not "%ValidationFailed%" == "1" (
        call :LDeploy
     )
  )
	if "%Uninstall%" == "1" (
      call :LRetract
  )

	goto LTerminate


@rem----------------------------------------------------------------------
@rem    LValidate
@rem----------------------------------------------------------------------
:LValidate
    echo Validating the content of solution %PackageName% ...
    echo.

    if exist "%SPFeaturesLocation%\DashboardWebPart" (
       echo Error: Feature folder DashboardWebPart already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPFeaturesLocation%\StoredProcessWebPart" (
       echo Error: Feature folder StoredProcessWebPart already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\IMAGES\SAS.WebParts\Folder.gif" (
       echo Error: Template file Folder.gif already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\IMAGES\SAS.WebParts\FolderOpen.gif" (
       echo Error: Template file FolderOpen.gif already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\IMAGES\SAS.WebParts\SASFolders.gif" (
       echo Error: Template file SASFolders.gif already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\IMAGES\SAS.WebParts\SASLogo.gif" (
       echo Error: Template file SASLogo.gif already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\IMAGES\SAS.WebParts\StoredProcess.gif" (
       echo Error: Template file StoredProcess.gif already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\LAYOUTS\SAS.WebParts\SelectDialog.aspx" (
       echo Error: Template file SelectDialog.aspx already exists in current SharePoint.
       set ValidationFailed=1
    )

    if exist "%SPTemplateLocation%\LAYOUTS\SAS.WebParts\SelectStoredProcessContents.aspx" (
       echo Error: Template file SelectStoredProcessContents.aspx already exists in current SharePoint.
       set ValidationFailed=1
    )

    goto :EOF


@rem----------------------------------------------------------------------
@rem    LDeploy
@rem----------------------------------------------------------------------
:LDeploy
    echo Adding solution %PackageName% to SharePoint ...
	"%SPAdminTool%" -o addsolution -filename "%PackageFile%"
	
    echo Deploying solution %PackageName% ...
	if  %SPVersion% equ 15 (
		"%SPAdminTool%" -o deploysolution -name "%PackageName%" -local -allowfulltrustbindlls -url %TargetWebUrl%
	) else (
		"%SPAdminTool%" -o deploysolution -name "%PackageName%" -local -allowCasPolicies -url %TargetWebUrl%
	)

    echo Activating feature DashboardWebPart ...
    "%SPAdminTool%" -o activatefeature -id 1204b2a5-8f7d-40b5-8679-dc960ba5aea1 -url %TargetSiteUrl%

    echo Activating feature StoredProcessWebPart ...
    "%SPAdminTool%" -o activatefeature -id 12040646-6b89-4e5a-9056-7050b19e685c -url %TargetSiteUrl%

    goto :EOF


@rem----------------------------------------------------------------------
@rem    LRetract
@rem----------------------------------------------------------------------
:LRetract
    echo Deactivating feature DashboardWebPart ...
    "%SPAdminTool%" -o deactivatefeature -id 1204b2a5-8f7d-40b5-8679-dc960ba5aea1 -url %TargetSiteUrl% -force

    echo Uninstalling feature DashboardWebPart ...
    "%SPAdminTool%" -o uninstallfeature -id 1204b2a5-8f7d-40b5-8679-dc960ba5aea1 -force

    echo Deactivating feature StoredProcessWebPart ...
    "%SPAdminTool%" -o deactivatefeature -id 12040646-6b89-4e5a-9056-7050b19e685c -url %TargetSiteUrl% -force

    echo Uninstalling feature StoredProcessWebPart ...
    "%SPAdminTool%" -o uninstallfeature -id 12040646-6b89-4e5a-9056-7050b19e685c -force

    echo Retracting solution %PackageName% ...
    "%SPAdminTool%" -o retractsolution -name "%PackageName%" -local -url %TargetWebUrl%

    echo Deleting solution %PackageName% from SharePoint ...
    "%SPAdminTool%" -o deletesolution -name "%PackageName%"

    goto :EOF


@rem----------------------------------------------------------------------
@rem    LTerminate
@rem----------------------------------------------------------------------
:LTerminate

    set SPLocation=
    set SPAdminTool=
    set PackageFile=
    set PackageName=
    set Install=
    set Uninstall=
    set TargetSiteUrl=
    set TargetWebUrl=
    set SPTemplateLocation=
    set SPFeaturesLocation=
    set SPSiteTemplateLocation=
    set SPWebTempFileLocation=
    set ValidationFailed=
    set UserInput=


popd
endlocal

